VerifierState

Struct VerifierState 

pub struct VerifierState<F: PrimeField> {
    pub round: usize,
    pub nv: usize,
    pub max_multiplicands: usize,
    pub finished: bool,
    pub polynomials_received: Vec<NatEvaluatedPolyWithoutConstant<F>>,
    pub randomness: Vec<F>,
    pub config: F::Config,
}
Sumcheck Verifier State.

Fields

round: usize

The current round number.

nv: usize

The number of variables the sumcheck polynomial is in.

max_multiplicands: usize

The degree of the polynomial.

finished: bool

true if the protocol has finished.

polynomials_received: Vec<NatEvaluatedPolyWithoutConstant<F>>

A list storing the univariate polynomial in evaluation form sent by the prover at each round so far.

randomness: Vec<F>

A list storing the randomness sampled by the verifier at each round so far.

config: F::Config

The field configuration to which all the field elements belong to.

Implementations

Source

impl<F: PrimeField> VerifierState<F>

pub fn new(nvars: usize, degree: usize, config: &F::Config) -> Self

Initialize the verifier state.

Source

impl<F: FromPrimitiveWithConfig> VerifierState<F>

pub fn verify_round( &mut self, prover_msg: &ProverMsg<F>, transcript: &mut impl Transcript, ) -> F
where F::Inner: ConstTranscribable,

Run verifier at current round, given prover message.

Samples a Fiat-Shamir challenge from the transcript and delegates to Self::verify_round_with_challenge. Returns the sampled challenge.

pub fn verify_round_with_challenge( &mut self, prover_msg: &ProverMsg<F>, challenge: F, )

Processes one round of the sumcheck protocol given an explicit challenge. Stores the prover’s round polynomial and the challenge, then advances the round counter. Actual consistency checks are deferred to Self::check_and_generate_subclaim.

pub fn check_and_generate_subclaim( self, asserted_sum: F, ) -> Result<Subclaim<F>, SumCheckError<F>>

Verify the sumcheck phase, and generate the subclaim.

The verifier reconstructs the missing constant term under the assumption that P(0) + P(1) == expected. If the asserted sum is correct, then the multilinear polynomial evaluated at subclaim.point is subclaim.expected_evaluation.